Module apply

Module apply 

Structs

ApplyResult
Result of applying rust-bucket to a target directory

Enums

ApplyError
Errors that can occur during the apply operation

Functions

apply_init
Apply rust-bucket to a target directory for the first time.
apply_update
Apply rust-bucket to a target directory in update mode (subsequent runs).