check_conflicts

Function check_conflicts 

pub fn check_conflicts(target_dir: &Path) -> Vec<PathBuf>
Check for conflicts between managed files and existing files in a target directory

Arguments

  • target_dir - Directory to check for conflicting files

Returns

A vector of paths to files that would conflict with managed files. Returns an empty vector if no conflicts are found.