Structs
- Apply
Result - Result of applying rust-bucket to a target directory
Enums
- Apply
Error - Errors that can occur during the apply operation
Functions
- apply_
init - Apply rust-bucket to a target directory for the first time.
- apply_
update - Apply rust-bucket to a target directory in update mode (subsequent runs).