prompt_test_timeout

Function prompt_test_timeout 

pub fn prompt_test_timeout() -> Result<u32, CliError>
Prompt the user for a test timeout value

Reads from stdin and validates the input is a positive integer. Returns 120 as the default if the user provides empty input.

Errors

Returns CliError::Io if reading from stdin fails. Returns CliError::InvalidInput if the input cannot be parsed as a positive integer.