Skip to main contentModule generator
Source - GeneratorError
- Errors that can occur during template generation
- check_conflicts
- Check for conflicts between managed files and existing files in a target directory
- create_claude_symlink
- Create the CLAUDE.md symlink pointing to AGENTS.md
- ensure_gitignore
- Ensure .gitignore contains all required lines, appending any that are missing.
- has_rust_bucket_toml
- Check if a target directory contains a rust-bucket.toml marker file
- render
- Render templates from a template directory to an output directory
- seed_style_guide
- Seed STYLE_GUIDE.md if missing, or replace it if it’s a stale managed file.