Module generator

Module generator 

Enums

GeneratorError
Errors that can occur during template generation

Functions

check_conflicts
Check for conflicts between managed files and existing files in a target directory
create_claude_symlink
Create the CLAUDE.md symlink pointing to AGENTS.md
has_rust_bucket_toml
Check if a target directory contains a rust-bucket.toml marker file
render
Render templates from a template directory to an output directory