Enums
- Generator
Error - Errors that can occur during template generation
Functions
- check_
conflicts - Check for conflicts between managed files and existing files in a target directory
- create_
claude_ symlink - Create the CLAUDE.md symlink pointing to AGENTS.md
- has_
rust_ bucket_ toml - Check if a target directory contains a rust-bucket.toml marker file
- render
- Render templates from a template directory to an output directory